==> zio-aws-sagemaker_2.12-5.17.129.2-sources.jar: zio/aws/sagemaker/model/PendingDeploymentSummary.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.sagemaker.model.primitives.{Timestamp, EndpointConfigName}
import scala.jdk.CollectionConverters._
final case class PendingDeploymentSummary(
    endpointConfigName: EndpointConfigName,
    productionVariants: Option[
      Iterable[zio.aws.sagemaker.model.PendingProductionVariantSummary]
    ] = None,
    startTime: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary = {
    import PendingDeploymentSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary
      .builder()
      .endpointConfigName(
        EndpointConfigName.unwrap(endpointConfigName): java.lang.String
      )
      .optionallyWith(
        productionVariants.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.productionVariants)
      .optionallyWith(startTime.map(value => Timestamp.unwrap(value): Instant))(
        _.startTime
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.PendingDeploymentSummary.ReadOnly =
    zio.aws.sagemaker.model.PendingDeploymentSummary.wrap(buildAwsValue())
}
object PendingDeploymentSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.PendingDeploymentSummary =
      zio.aws.sagemaker.model.PendingDeploymentSummary(
        endpointConfigName,
        productionVariants.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        startTime.map(value => value)
      )
    def endpointConfigName: EndpointConfigName
    def productionVariants: Option[
      List[zio.aws.sagemaker.model.PendingProductionVariantSummary.ReadOnly]
    ]
    def startTime: Option[Timestamp]
    def getEndpointConfigName: ZIO[Any, Nothing, EndpointConfigName] =
      ZIO.succeed(endpointConfigName)
    def getProductionVariants: ZIO[Any, AwsError, List[
      zio.aws.sagemaker.model.PendingProductionVariantSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("productionVariants", productionVariants)
    def getStartTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("startTime", startTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary
  ) extends zio.aws.sagemaker.model.PendingDeploymentSummary.ReadOnly {
    override val endpointConfigName: EndpointConfigName =
      zio.aws.sagemaker.model.primitives
        .EndpointConfigName(impl.endpointConfigName())
    override val productionVariants: Option[
      List[zio.aws.sagemaker.model.PendingProductionVariantSummary.ReadOnly]
    ] = scala
      .Option(impl.productionVariants())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.sagemaker.model.PendingProductionVariantSummary.wrap(item)
        }.toList
      )
    override val startTime: Option[Timestamp] = scala
      .Option(impl.startTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary
  ): zio.aws.sagemaker.model.PendingDeploymentSummary.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_2.12-6.20.103.1-sources.jar: zio/aws/sagemaker/model/PendingDeploymentSummary.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{Timestamp, EndpointConfigName}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class PendingDeploymentSummary(
    endpointConfigName: EndpointConfigName,
    productionVariants: Optional[
      Iterable[zio.aws.sagemaker.model.PendingProductionVariantSummary]
    ] = Optional.Absent,
    startTime: Optional[Timestamp] = Optional.Absent,
    shadowProductionVariants: Optional[
      Iterable[zio.aws.sagemaker.model.PendingProductionVariantSummary]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary = {
    import PendingDeploymentSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary
      .builder()
      .endpointConfigName(
        EndpointConfigName.unwrap(endpointConfigName): java.lang.String
      )
      .optionallyWith(
        productionVariants.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.productionVariants)
      .optionallyWith(startTime.map(value => Timestamp.unwrap(value): Instant))(
        _.startTime
      )
      .optionallyWith(
        shadowProductionVariants.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.shadowProductionVariants)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.PendingDeploymentSummary.ReadOnly =
    zio.aws.sagemaker.model.PendingDeploymentSummary.wrap(buildAwsValue())
}
object PendingDeploymentSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.PendingDeploymentSummary =
      zio.aws.sagemaker.model.PendingDeploymentSummary(
        endpointConfigName,
        productionVariants.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        startTime.map(value => value),
        shadowProductionVariants.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def endpointConfigName: EndpointConfigName
    def productionVariants: Optional[
      List[zio.aws.sagemaker.model.PendingProductionVariantSummary.ReadOnly]
    ]
    def startTime: Optional[Timestamp]
    def shadowProductionVariants: Optional[
      List[zio.aws.sagemaker.model.PendingProductionVariantSummary.ReadOnly]
    ]
    def getEndpointConfigName: ZIO[Any, Nothing, EndpointConfigName] =
      ZIO.succeed(endpointConfigName)
    def getProductionVariants: ZIO[Any, AwsError, List[
      zio.aws.sagemaker.model.PendingProductionVariantSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("productionVariants", productionVariants)
    def getStartTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("startTime", startTime)
    def getShadowProductionVariants: ZIO[Any, AwsError, List[
      zio.aws.sagemaker.model.PendingProductionVariantSummary.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "shadowProductionVariants",
      shadowProductionVariants
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary
  ) extends zio.aws.sagemaker.model.PendingDeploymentSummary.ReadOnly {
    override val endpointConfigName: EndpointConfigName =
      zio.aws.sagemaker.model.primitives
        .EndpointConfigName(impl.endpointConfigName())
    override val productionVariants: Optional[
      List[zio.aws.sagemaker.model.PendingProductionVariantSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.productionVariants())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.sagemaker.model.PendingProductionVariantSummary.wrap(item)
        }.toList
      )
    override val startTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.startTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val shadowProductionVariants: Optional[
      List[zio.aws.sagemaker.model.PendingProductionVariantSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.shadowProductionVariants())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.sagemaker.model.PendingProductionVariantSummary.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.PendingDeploymentSummary
  ): zio.aws.sagemaker.model.PendingDeploymentSummary.ReadOnly = new Wrapper(
    impl
  )
}
